==> istio-model-v1alpha3-6.8.1-sources.jar: io/fabric8/istio/api/internal/protobuf/types/ValueBoolValueFluent.java <==
package io.fabric8.istio.api.internal.protobuf.types;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ValueBoolValueFluent<A extends ValueBoolValueFluent<A>> extends BaseFluent<A>{
  public ValueBoolValueFluent() {
  }
  public ValueBoolValueFluent(ValueBoolValue instance) {
    instance = (instance != null ? instance : new ValueBoolValue());

    if (instance != null) {
      this.withBoolValue(instance.getBoolValue());
      this.withBoolValue(instance.getBoolValue());
    }
  }
  private Boolean boolValue;
  public Boolean getBoolValue() {
    return this.boolValue;
  }
  public A withBoolValue(Boolean boolValue) {
    this.boolValue=boolValue; return (A) this;
  }
  public boolean hasBoolValue() {
    return this.boolValue != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ValueBoolValueFluent that = (ValueBoolValueFluent) o;
    if (!java.util.Objects.equals(boolValue, that.boolValue)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(boolValue,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (boolValue != null) { sb.append("boolValue:"); sb.append(boolValue); }
    sb.append("}");
    return sb.toString();
  }
  public A withBoolValue() {
    return withBoolValue(true);
  }
  
}

==> istio-model-v1alpha3-6.9.0-sources.jar: io/fabric8/istio/api/internal/protobuf/types/ValueBoolValueFluent.java <==
package io.fabric8.istio.api.internal.protobuf.types;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ValueBoolValueFluent<A extends ValueBoolValueFluent<A>> extends BaseFluent<A>{
  public ValueBoolValueFluent() {
  }
  
  public ValueBoolValueFluent(ValueBoolValue instance) {
    this.copyInstance(instance);
  }
  private Boolean boolValue;
  
  protected void copyInstance(ValueBoolValue instance) {
    instance = (instance != null ? instance : new ValueBoolValue());
  
    if (instance != null) {
        this.withBoolValue(instance.getBoolValue());
        this.withBoolValue(instance.getBoolValue());
      }
  }
  
  public Boolean getBoolValue() {
    return this.boolValue;
  }
  
  public A withBoolValue(Boolean boolValue) {
    this.boolValue=boolValue; return (A) this;
  }
  
  public boolean hasBoolValue() {
    return this.boolValue != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ValueBoolValueFluent that = (ValueBoolValueFluent) o;
    if (!java.util.Objects.equals(boolValue, that.boolValue)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(boolValue,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (boolValue != null) { sb.append("boolValue:"); sb.append(boolValue); }
    sb.append("}");
    return sb.toString();
  }
  
  public A withBoolValue() {
    return withBoolValue(true);
  }
  

}
